require 'fileutils'
require 'rails/generators'

module Jabysoft
  module Generators
    class SetupGenerator < ::Rails::Generators::Base
      desc 'Prepare your rails application to Jabysoft standards'
      source_root ::File.expand_path('../templates', __FILE__)

      def create_layout
        remove_file "app/views/layouts/application.html.erb"
        template "layouts/application.html.haml", "app/views/layouts/application.html.haml"
        template "layouts/admin.html.haml", "app/views/layouts/admin.html.haml"
      end

      def create_stylesheets
        copy_file "assets/stylesheets/bootstrap-variables.scss", "app/assets/stylesheets/bootstrap-variables.scss"
        remove_file "assets/stylesheets/scaffold.scss"
      end

      def create_spec_rails_helper
        copy_file "spec/rails_helper.rb", "spec/rails_helper.rb"
        copy_file "spec/spec_helper.rb", "spec/spec_helper.rb"
        copy_file ".rspec", ".rspec"
      end

      def inject_backbone
        application_js_path = 'app/assets/javascripts/application.js'
        application_sass_path = 'app/assets/stylesheets/application.scss'

        if ::File.exist?('app/assets/stylesheets/application.css')
          css_file = ::File.open('app/assets/stylesheets/application.css')
          FileUtils.mv css_file, "#{File.dirname(css_file)}/#{File.basename(css_file,'.*')}.scss"
        end

        if ::File.exist?(::File.join(destination_root, application_js_path))
          inject_into_file application_js_path, before: '//= require_tree' do
            "//= require jabysoft\n"
          end
        end

        if ::File.exist?(::File.join(destination_root, application_sass_path))
          inject_into_file application_sass_path, after: ' */' do
            "\n\n@import 'jabysoft'\n"
          end
        end
      end

      def create_gemfile
        remove_file "Gemfile"
        remove_file "Gemfile.lock"
        copy_file "Gemfile", "Gemfile"
        run('bundle install')
      end
    end
  end
end
